library("testthat")
library("rKolada")

# test_check("rKolada")
